@@ -1,7 +1,6 @@
 /*
-
     A little library to do quarternion arithmetic
-    Copyright (C) 2003  John Darrington
+    Copyright (C) 2003, 2011  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +20,8 @@
 
 #include "txfm.h"
 
-struct quarternion {
+struct quarternion
+{
   float w;
   float x;
   float y;
@@ -31,18 +31,18 @@ struct quarternion {
 typedef struct quarternion Quarternion;
 
 
-void quarternion_from_rotation (Quarternion *q,  vector u,  float theta) ;
+void quarternion_get_inverse (Quarternion * inv, const Quarternion * q);
 
-void quarternion_print (const Quarternion *q) ;
+void quarternion_from_rotation (Quarternion * q, const vector u, float theta);
 
-void quarternion_to_matrix (Matrix M,  const Quarternion *q) ;
+void quarternion_dump (const Quarternion * q);
+
+void quarternion_to_matrix (Matrix M, const Quarternion * q);
 
 /* Pre multiply q1 by q2 */
-void quarternion_pre_mult (Quarternion *q1,  const Quarternion *q2) ;
+void quarternion_pre_mult (Quarternion * q1, const Quarternion * q2);
 
-void quarternion_set_to_unit (Quarternion *q) ;
+void quarternion_set_to_unit (Quarternion * q);
 
 
 #endif /* QUARTERNION_H */
-
-
