@@ -1,7 +1,7 @@
 /*
     A system to permit user selection of a block and rotation axis
     of a magic cube.
-    Copyright (C) 1998  John Darrington
+    Copyright (C) 1998, 2011  John Darrington
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,35 +22,41 @@
 #include <GL/gl.h>
 #include <gtk/gtk.h>
 
-struct facet_selection {
-	int block;
-	int face;
-	int quadrant;
-} ;
+#include "cubeview.h"
+
+struct facet_selection
+{
+  int block;
+  int face;
+  int quadrant;
+};
+
+struct cublet_selection;
+
+typedef void select_func (struct cublet_selection *, gpointer data);
 
 /* Initialise the selection library */
-void initSelection (int holdoff,  GLdouble precision,  void (*do_this)(void) );
+struct cublet_selection *select_create (GtkWidget * w, int holdoff,
+					double precision,
+					select_func * do_this, gpointer data);
+
+void select_destroy (struct cublet_selection *);
 
 /* Temporarily enable/disable selection */
-void disableSelection (void);
-void enableSelection (void);
+void select_disable (struct cublet_selection *);
+void select_enable (struct cublet_selection *);
+
+
+void select_update (GbkCubeview * cv, struct cublet_selection *cs);
 
 /* Return  a pointer to a structre containing the selected items */
-struct facet_selection *selectedItems (void);
+const struct facet_selection *select_get (const struct cublet_selection *cs);
 
-/* Force an update of the selected block */
-void updateSelection (void);
-
-/* returns 1 if a block has been selected */
-int itemIsSelected (void);
+/* returns true if a block has been selected */
+gboolean select_is_selected (const struct cublet_selection *cs);
 
 
-int get_widget_height (GtkWidget *w);
-
-
-/* Identify the block at screen co-ordinates x,  y */
-struct facet_selection* pickPolygons (int x,  int y) ;
-
+GtkWidget *cublet_selection_get_widget (const struct cublet_selection *cs);
 
 
 #endif
